==> cscec5b-test-api-3.0.1-20231008.073019-17-sources.jar: com/ejianc/business/test/vo/ReportVO.java <==
package com.ejianc.business.test.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 汇总信息实体VO
 * 
 * @author generator
 * 
 */
public class ReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Integer projectNum; // 项目数量
    private Integer repeatProjectNum; // 重复项目个数

    private BigDecimal sumContractMny; // 累计合同金额（万元）
    private BigDecimal sumBuildHeight; // 建筑物总高度（米）
    private BigDecimal sumRoadLength; // 公/铁路总长度（千米）
    private BigDecimal sumAssembArea; // 装配式建筑总面积（万平方米）
    private BigDecimal sumAssembContractMny; // 装配式总合同额（万元）
    private BigDecimal sumPcNum; // PC部件数量（万立方）

    private String sgdw; // 施工单位
    private BigDecimal contractMny; // 合同额（万元）

    private String period; // 时期
    private Integer projNum; // 业绩数量

    public Integer getProjectNum() {
        return projectNum;
    }

    public void setProjectNum(Integer projectNum) {
        this.projectNum = projectNum;
    }

    public Integer getRepeatProjectNum() {
        return repeatProjectNum;
    }

    public void setRepeatProjectNum(Integer repeatProjectNum) {
        this.repeatProjectNum = repeatProjectNum;
    }

    public BigDecimal getSumContractMny() {
        return sumContractMny;
    }

    public void setSumContractMny(BigDecimal sumContractMny) {
        this.sumContractMny = sumContractMny;
    }

    public BigDecimal getSumBuildHeight() {
        return sumBuildHeight;
    }

    public void setSumBuildHeight(BigDecimal sumBuildHeight) {
        this.sumBuildHeight = sumBuildHeight;
    }

    public BigDecimal getSumRoadLength() {
        return sumRoadLength;
    }

    public void setSumRoadLength(BigDecimal sumRoadLength) {
        this.sumRoadLength = sumRoadLength;
    }

    public BigDecimal getSumAssembArea() {
        return sumAssembArea;
    }

    public void setSumAssembArea(BigDecimal sumAssembArea) {
        this.sumAssembArea = sumAssembArea;
    }

    public BigDecimal getSumAssembContractMny() {
        return sumAssembContractMny;
    }

    public void setSumAssembContractMny(BigDecimal sumAssembContractMny) {
        this.sumAssembContractMny = sumAssembContractMny;
    }

    public BigDecimal getSumPcNum() {
        return sumPcNum;
    }

    public void setSumPcNum(BigDecimal sumPcNum) {
        this.sumPcNum = sumPcNum;
    }

    public String getSgdw() {
        return sgdw;
    }

    public void setSgdw(String sgdw) {
        this.sgdw = sgdw;
    }

    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }

    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }

    public Integer getProjNum() {
        return projNum;
    }

    public void setProjNum(Integer projNum) {
        this.projNum = projNum;
    }
}

==> cscec5b-test-api-3.0.1-20231019.134736-20-sources.jar: com/ejianc/business/test/vo/ReportVO.java <==
package com.ejianc.business.test.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 汇总信息实体VO
 * 
 * @author generator
 * 
 */
public class ReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Integer corpNum; // 公司数量
    private Integer projectNum; // 项目数量
    private Integer signNum; // 签约名义数量
    private Integer repeatProjectNum; // 重复项目个数

    private BigDecimal sumContractMny; // 累计合同金额（万元）
    private BigDecimal sumBuildArea; // 建筑物总面积
    private BigDecimal sumBuildHeight; // 建筑物总高度（米）

    private BigDecimal sumAssembArea; // 装配式建筑总面积（万平方米）
    private BigDecimal sumAssembContractMny; // 装配式总合同额（万元）
    private BigDecimal sumPcNum; // PC部件数量（万立方）
    private BigDecimal sumBridgeSpan; // 桥梁跨度（米）
    private BigDecimal sumPipeLength; // 管网(廊)长度（公里）
    private BigDecimal sumRoadLength; // 公/铁路总长度（千米）

    private String sgdw; // 施工单位
    private BigDecimal contractMny; // 合同额（万元）

    private String period; // 时期
    private Integer projNum; // 业绩数量

    public Integer getCorpNum() {
        return corpNum;
    }

    public void setCorpNum(Integer corpNum) {
        this.corpNum = corpNum;
    }

    public Integer getProjectNum() {
        return projectNum;
    }

    public void setProjectNum(Integer projectNum) {
        this.projectNum = projectNum;
    }

    public Integer getSignNum() {
        return signNum;
    }

    public void setSignNum(Integer signNum) {
        this.signNum = signNum;
    }

    public Integer getRepeatProjectNum() {
        return repeatProjectNum;
    }

    public void setRepeatProjectNum(Integer repeatProjectNum) {
        this.repeatProjectNum = repeatProjectNum;
    }

    public BigDecimal getSumContractMny() {
        return sumContractMny;
    }

    public void setSumContractMny(BigDecimal sumContractMny) {
        this.sumContractMny = sumContractMny;
    }

    public BigDecimal getSumBuildArea() {
        return sumBuildArea;
    }

    public void setSumBuildArea(BigDecimal sumBuildArea) {
        this.sumBuildArea = sumBuildArea;
    }

    public BigDecimal getSumBuildHeight() {
        return sumBuildHeight;
    }

    public void setSumBuildHeight(BigDecimal sumBuildHeight) {
        this.sumBuildHeight = sumBuildHeight;
    }

    public BigDecimal getSumAssembArea() {
        return sumAssembArea;
    }

    public void setSumAssembArea(BigDecimal sumAssembArea) {
        this.sumAssembArea = sumAssembArea;
    }

    public BigDecimal getSumAssembContractMny() {
        return sumAssembContractMny;
    }

    public void setSumAssembContractMny(BigDecimal sumAssembContractMny) {
        this.sumAssembContractMny = sumAssembContractMny;
    }

    public BigDecimal getSumPcNum() {
        return sumPcNum;
    }

    public void setSumPcNum(BigDecimal sumPcNum) {
        this.sumPcNum = sumPcNum;
    }

    public BigDecimal getSumBridgeSpan() {
        return sumBridgeSpan;
    }

    public void setSumBridgeSpan(BigDecimal sumBridgeSpan) {
        this.sumBridgeSpan = sumBridgeSpan;
    }

    public BigDecimal getSumPipeLength() {
        return sumPipeLength;
    }

    public void setSumPipeLength(BigDecimal sumPipeLength) {
        this.sumPipeLength = sumPipeLength;
    }

    public BigDecimal getSumRoadLength() {
        return sumRoadLength;
    }

    public void setSumRoadLength(BigDecimal sumRoadLength) {
        this.sumRoadLength = sumRoadLength;
    }

    public String getSgdw() {
        return sgdw;
    }

    public void setSgdw(String sgdw) {
        this.sgdw = sgdw;
    }

    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }

    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }

    public Integer getProjNum() {
        return projNum;
    }

    public void setProjNum(Integer projNum) {
        this.projNum = projNum;
    }
}
